@@ -440,7 +440,7 @@ class Model:
         variables = self.variables
         for variable in variables:
             if 'table' in data:
-                n=1
+                n=0
                 for table in data['table']:
                     if variable.name in table:
                         n=n+1
@@ -458,7 +458,7 @@ class Model:
         for variable in self.variables:
             worksheet.cell(variable.row, variable.column, variable.value)
         for style in self.styles:
-            worksheet[style.name].data_type = copy(style.data_type)
+            #worksheet[style.name].data_type = copy(style.data_type)
             worksheet[style.name].font = copy(style.font)
             worksheet[style.name].fill = copy(style.fill)
             worksheet[style.name].border = copy(style.border)
